from OpenGL.GL import *
from OpenGL.GLU import *
from OpenGL.GLUT import *

# Initial square position and size
x1 = 10.0
y1 = -70.0
rsize = 25.
# Step size in x and y directions
# (number of pixels to move each time)
xstep = 0.9
ystep = 1.1


# Keep track of windows changing width and height
max_x = 200.
max_y = 150.

min_x = -200.
min_y = -150.

A = (max_x - min_x) / (max_y - min_y)

def RenderScene():
    """ Called to draw scene """
    # Clear the window with current clearing color
    glClear(GL_COLOR_BUFFER_BIT)
    
    
    # Meglio usare glScissor...
    # Set current drawing color to red # R G B
    glColor3f(0.8, 0.8, 0.8)

    # Draw a filled rectangle with current color
    glRectf(min_x, min_y, max_x, max_y)

    # Set current drawing color to red # R G B
    glColor3f(1.0, 0.0, 0.0)

    # Draw a filled rectangle with current color
    glRectf(x1, y1, x1 + rsize, y1 + rsize)


    # test
    glColor3f(0.0, 1.0, 0.0)
    glRectf(min_x, min_y, min_x + rsize, min_y + rsize)
    glColor3f(0.0, 1.0, 0.0)
    glRectf(max_x - rsize, min_y, max_x - rsize + rsize, min_y + rsize)
    glColor3f(0.0, 1.0, 0.0)
    glRectf(min_x, max_y - rsize, min_x + rsize, max_y - rsize + rsize)
    glColor3f(0.0, 1.0, 0.0)
    glRectf(max_x - rsize, max_y - rsize, max_x - rsize + rsize, max_y - rsize + rsize)
    
    # Flush drawing commands and swap
    glutSwapBuffers()


def SetupRC():
    """ Set up the rendering state """
    # Set clear color to blue 
    glClearColor(0.0, 0.0, 0.0, 1.0) 


def ChangeSize(w, h):
    """ Called by GLUT library when the window has changed size """


    # Set Viewport to window dimensions 
    aspectRatio = float(w) / float(h) 
    if aspectRatio >= A:
        glViewport(int((w - h * A)/2), 0, int(A * h), h)        
        
    else: # a <= A
        glViewport(0, int((h - w / A)/2), w, int(w / A))

    # Reset coordinate system 
    glMatrixMode(GL_PROJECTION)
    glLoadIdentity()

    # Establish clipping volume (left, right, bottom, top, near, far)   
    glOrtho (min_x, max_x, 
             min_y, max_y,
              1.0, -1.0)
                
    
    glMatrixMode(GL_MODELVIEW) 
    glLoadIdentity()

def TimerFunction(value):
    """ Called by GLUT library when idle (window not being resized or moved) """
    global x1,y1,rsize,xstep,ystep
    
    #print "x1: %d, y1: %d" % (x1, y1)
    
    # Reverse direction when you reach left or right edge
    if (x1 > (max_x - rsize)) or (x1 < min_x):
        xstep = -xstep
        
    # Reverse direction when you reach top or bottom edge
    if (y1 > max_y - rsize) or (y1 < min_y):
        ystep = -ystep
        
    # Actually move the square
    x1 += xstep
    y1 += ystep
    
    # Check bounds. This is in case the window is made
    # smaller while the rectangle is bouncing and the
    # rectangle suddenly finds itself outside the new
    # clipping volume
    # if(x1 > (windowWidth-rsize + xstep)):
    #     x1 = windowWidth-rsize-1
    # elif(x1 < -(windowWidth + xstep)):
    #     x1 = - windowWidth -1
    # if(y1 > (windowHeight + ystep)):
    #     y1 = windowHeight-1
    # elif(y1 < -(windowHeight - rsize + ystep)):
    #     y1 = -windowHeight + rsize -1
    # Redraw the scene with new coordinates
    
    glutPostRedisplay()
    glutTimerFunc(12,TimerFunction, 1)

# Main program entry point
if __name__ == "__main__":
    glutInit()
    glutInitDisplayMode(GLUT_DOUBLE | GLUT_RGB)
    glutInitWindowSize(800,800)
    glutCreateWindow("Bounce")
    glutDisplayFunc(RenderScene)
    glutReshapeFunc(ChangeSize)
    glutTimerFunc(33, TimerFunction, 1)
    SetupRC()
    glutMainLoop()
