"""/*
 *  light.c
 *  This program demonstrates the use of the OpenGL lighting
 *  model.  A sphere is drawn using a grey material characteristic.
 *  A single light source illuminates the object.
 */"""
from OpenGL.GL import *
from OpenGL.GLU import *
from OpenGL.GLUT import *

"""/*  Initialize material property, light source, lighting model,
 *  and depth buffer.
 */"""

def init():

   ambient =  0.7, 0.7, 0.7, 1.0 
   diffuse =  1.0, 1.0, 1.0, 1.0 
   specular =  1.0, 1.0, 1.0, 1.0 
   position =  0.0, 3.0, 2.0, 0.0 
   lmodel_ambient =  0.4, 0.4, 0.4, 1.0 
   local_view =  0.0 

   glClearColor(0.0, 0.1, 0.1, 0.0)
   glEnable(GL_DEPTH_TEST)
   glShadeModel(GL_SMOOTH)

   glLightfv(GL_LIGHT0, GL_AMBIENT, ambient)
   glLightfv(GL_LIGHT0, GL_DIFFUSE, diffuse)
   glLightfv(GL_LIGHT0, GL_POSITION, position)
   glLightModelfv(GL_LIGHT_MODEL_AMBIENT, lmodel_ambient)
   glLightModelfv(GL_LIGHT_MODEL_LOCAL_VIEWER, local_view)

   glEnable(GL_LIGHTING)
   glEnable(GL_LIGHT0)

def display():

   glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)
   glutSolidSphere (1.0, 40, 16)
   glFlush ()


def reshape (w, h):

   glViewport (0, 0, w, h)
   glMatrixMode (GL_PROJECTION)
   glLoadIdentity()
   if (w <= h):
      glOrtho (-1.5, 1.5, -1.5*float(h)/float(w),
         1.5*float(h)/float(w), -10.0, 10.0)
   else:
      glOrtho (-1.5*float(w)/float(h),
         1.5*float(w)/float(h), -1.5, 1.5, -10.0, 10.0)
   glMatrixMode(GL_MODELVIEW)
   glLoadIdentity()


# Main program entry point
if __name__ == "__main__":
   glutInit()
   glutInitDisplayMode (GLUT_SINGLE | GLUT_RGB | GLUT_DEPTH)
   glutInitWindowSize (500, 500) 
   glutInitWindowPosition (100, 100)
   glutCreateWindow ("Ligth")
   init ()
   glutDisplayFunc(display) 
   glutReshapeFunc(reshape)
   glutMainLoop()

